-- MyBigClock v8.0 --

-- Clock local variables --

local MYBIGCLOCK_LOCK;


-- Clock event functions --


-- OnLoad event
function MyBigClock_OnLoad(self)

	-- Register the events that need to be watched
	self:RegisterEvent("ADDON_LOADED");

end

-- OnEvent event
function MyBigClock_OnEvent(self, event, ...)

	-- Check the current event
	if (event == "ADDON_LOADED") then
		local addon = select(1, ...);
		if (addon == "MyBigClock") then
			-- Initialize the addon
			MyBigClock_Initialize();
		end
		return;
	end

end

-- OnUpdate event
function MyBigClock_OnUpdate(self, elapsed)

	-- Check if an update is needed
	if ( self.timeLeft <= elapsed ) then
		-- Reset the time left
		self.timeLeft = FRAMERATE_FREQUENCY;
		-- local time
		local dateInfo = date("*t");
		local hour, minute = dateInfo.hour, dateInfo.min;
		-- screw the server time

		-- Check the minutes
		if (minute >= 60) then
			minute = minute - 60;
			hour = hour + 1;
		end
		-- Check the hours
		if (hour >= 24) then
			hour = hour - 24;
		elseif (hour < 0) then
			hour = hour + 24;
		end
		-- Check the time format option
		if (MyBigClockOptions.timeFormat == 24) then
			MyBigClockText:SetText(format((TIME_TWENTYFOURHOURS), hour, minute));
		else
			local pm = 0;
			if (hour >= 12) then
				pm = 1;
			end
			if (hour > 12) then
				hour = hour - 12;
			end
			if (hour == 0) then
				hour = 12;
			end
			if (pm == 0) then
				MyBigClockText:SetText(string.gsub(string.sub(format((TIME_TWELVEHOURAM), hour, minute),1,5)," ","").." AM");
			else
				MyBigClockText:SetText(string.gsub(string.sub(format((TIME_TWELVEHOURPM), hour, minute),1,5)," ","").." PM");
			end
			MyBigClockText:SetTextColor(1.0, 1.0, 1.0);
		end
	else
		self.timeLeft = self.timeLeft - elapsed;
	end

end

-- MyBigClock Options Menu --

-- OnMouseDown event
function MyBigClock_OnMouseDown(self, button)

	-- Check the button used
	if (not self.isLocked and button == "LeftButton") then
		self:StartMoving();
		self.isMoving = true;
	end

end;

-- OnMouseUp event
function MyBigClock_OnMouseUp(self, button)

	-- Check the button used
	if (button == "LeftButton") then
		if (self.isMoving) then
			self:StopMovingOrSizing();
			self.isMoving = false;
		end
    elseif (button == "RightButton") then
		ToggleDropDownMenu(1, nil, MyBigClockDropDownMenu, "cursor");
	
		-- Play the open sound
		DoEmote("READ", nil, true);
		PlaySound(SOUNDKIT.IG_CHAT_SCROLL_DOWN);
	end

end;


-- Initialize the Options
function MyBigClock_Initialize()

	-- Toggle the clock frame lock
	MyBigClock_ToggleLock();
	
	-- Initialize the dropdown menu
	UIDropDownMenu_Initialize(MyBigClockDropDownMenu, MyBigClockDropDownMenu_Initialize, "MENU");
	
	-- Initialize the options frame
	MyBigClockOptionsFrame_Initialize();
	
	-- Update the display
	MyBigClock_Update();

end

-- Populate the dropdown menu
function MyBigClockDropDownMenu_Initialize()

	local info;
	
	info = {};
	info.text = "MyBigClock";
	info.isTitle = 1;
	info.notCheckable = 1;
	UIDropDownMenu_AddButton(info);
	
	info = {};
	info.text = MYBIGCLOCK_LOCK;
	info.func = MyBigClock_ToggleLock;
	info.notCheckable = 1;
	UIDropDownMenu_AddButton(info);
	
	info = {};
	info.text = "Options";
	info.func = MyBigClockOptionsFrame_Toggle;
	info.notCheckable = 1;
	UIDropDownMenu_AddButton(info);
	
	info = {};
	info.text = CANCEL;
	info.func = MyBigClockDropDownMenu_Cancel;
	info.notCheckable = 1;
	UIDropDownMenu_AddButton(info);

end


-- Clock display functions --


-- Update the display
function MyBigClock_Update()

	-- Reset the update timer
	MyBigClock.timeLeft = 0;

end


-- Toggle the clock frame lock
function MyBigClock_ToggleLock()

	-- Check the clock frame lock
	if (MyBigClock.isLocked) then
		MyBigClock.isLocked = nil;
		MYBIGCLOCK_LOCK = "Lock Position";
	else
		MyBigClock.isLocked = 1;
		MYBIGCLOCK_LOCK = "Unlock Position";
	end

end

-- Cancel the dropdown menu
function MyBigClockDropDownMenu_Cancel()
	-- Play the close sound
	CancelEmote();
	PlaySound(SOUNDKIT.IG_QUEST_LOG_CLOSE);
end

-- Other clock functions --


-- Options global variables --


MyBigClockOptions = {};


-- Options event functions --


-- OnShow event
function MyBigClockOptionsFrame_OnShow(self)
	-- Play the open sound
	DoEmote("READ", nil, true);
	PlaySound(SOUNDKIT.IG_CHAT_SCROLL_DOWN);

	-- Use a smaller font for dropdown menus
	MYUIDROPDOWNMENU_BUTTON_HEIGHT = UIDROPDOWNMENU_BUTTON_HEIGHT;
	UIDROPDOWNMENU_BUTTON_HEIGHT = 12;
	
	-- Update the display
	MyBigClockOptionsFrame_Update();

end

-- OnHide event
function MyBigClockOptionsFrame_OnHide(self)
	-- Play the close sound
	CancelEmote();
	PlaySound(SOUNDKIT.IG_QUEST_LOG_CLOSE);

	-- Restore the standard font for dropdown menus
	UIDROPDOWNMENU_BUTTON_HEIGHT = MYUIDROPDOWNMENU_BUTTON_HEIGHT;

end


-- Timeformat dropdown menu OnClick event
function MyBigClockOptionsFrameTimeFormatDropDown_OnClick(self)

	-- Save the selected timeformat
	UIDropDownMenu_SetSelectedValue(MyBigClockOptionsFrameTimeFormatDropDown, self.value);
	MyBigClockOptions.timeFormat = self.value;

end


-- Initialize options functions --


-- Initialize the options frame
function MyBigClockOptionsFrame_Initialize()

	-- Initialize the options
	MyBigClockOptionsFrame_InitializeOptions();
	
	-- Initialize the options checkbutton
	UIDropDownMenu_Initialize(MyBigClockOptionsFrameTimeFormatDropDown, MyBigClockOptionsFrameTimeFormatDropDown_Initialize);
	UIDropDownMenu_SetWidth(MyBigClockOptionsFrameTimeFormatDropDown, 80);
	
end

-- Initialize the options
function MyBigClockOptionsFrame_InitializeOptions()

	-- Check the timeformat option
	if (not MyBigClockOptions.timeFormat) then
		MyBigClockOptions.timeFormat = 12;
	end

end

-- Initialize the timeformat dropdown menu
function MyBigClockOptionsFrameTimeFormatDropDown_Initialize()

	local info;
	
	info = {};
	info.text = "12".." Hours";
	info.func = MyBigClockOptionsFrameTimeFormatDropDown_OnClick;
	info.value = 12;
	UIDropDownMenu_AddButton(info);
	
	info = {};
	info.text = "24".." Hours";
	info.func = MyBigClockOptionsFrameTimeFormatDropDown_OnClick;
	info.value = 24;
	UIDropDownMenu_AddButton(info);

end


-- Options display functions --


-- Update the display
function MyBigClockOptionsFrame_Update()

	-- Set the timeformat dropdown menu value
	UIDropDownMenu_SetSelectedValue(MyBigClockOptionsFrameTimeFormatDropDown, MyBigClockOptions.timeFormat);
	UIDropDownMenu_SetText(MyBigClockOptionsFrameTimeFormatDropDown, MyBigClockOptions.timeFormat.." Hours");

end

-- Toggle the options frame display
function MyBigClockOptionsFrame_Toggle()

	-- Check if the options frame is visible
	if(MyBigClockOptionsFrame:IsVisible()) then
		MyBigClockOptionsFrame:Hide();
	else
		MyBigClockOptionsFrame:Show();
	end

end

